==> dps-data-model-0.0.18-sources.jar: pl/topteam/dps/model/main_gen/InformacjaDodatkowaRozszerzenie.java <==
package pl.topteam.dps.model.main_gen;

import pl.topteam.dps.enums.TypRozszerzeniaInformacji;
import pl.topteam.dps.generic.GenericDPSObject;

public abstract class InformacjaDodatkowaRozszerzenie extends GenericDPSObject {
    /**
     * INFORMACJA_DODATKOWA_ROZSZERZENIE.ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long id;

    /**
     * INFORMACJA_DODATKOWA_ROZSZERZENIE.INFORMACJA_DODATKOWA_ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long informacjaDodatkowaId;

    /**
     * INFORMACJA_DODATKOWA_ROZSZERZENIE.WARTOSC_TR
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long wartoscTr;

    /**
     * INFORMACJA_DODATKOWA_ROZSZERZENIE.TYP
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private TypRozszerzeniaInformacji typ;

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    private static final long serialVersionUID = 1L;

    /**
     * @return INFORMACJA_DODATKOWA_ROZSZERZENIE.ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public Long getId() {
        return id;
    }

    /**
     * INFORMACJA_DODATKOWA_ROZSZERZENIE.ID
     *
     * @param id
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setId(Long id) {
        this.id = id;
    }

    /**
     * @return INFORMACJA_DODATKOWA_ROZSZERZENIE.INFORMACJA_DODATKOWA_ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Long getInformacjaDodatkowaId() {
        return informacjaDodatkowaId;
    }

    /**
     * INFORMACJA_DODATKOWA_ROZSZERZENIE.INFORMACJA_DODATKOWA_ID
     *
     * @param informacjaDodatkowaId
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setInformacjaDodatkowaId(Long informacjaDodatkowaId) {
        this.informacjaDodatkowaId = informacjaDodatkowaId;
    }

    /**
     * @return INFORMACJA_DODATKOWA_ROZSZERZENIE.WARTOSC_TR
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Long getWartoscTr() {
        return wartoscTr;
    }

    /**
     * INFORMACJA_DODATKOWA_ROZSZERZENIE.WARTOSC_TR
     *
     * @param wartoscTr
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setWartoscTr(Long wartoscTr) {
        this.wartoscTr = wartoscTr;
    }

    /**
     * @return INFORMACJA_DODATKOWA_ROZSZERZENIE.TYP
     * @mbggenerated 2014-03-10 10:45:37
     */
    public TypRozszerzeniaInformacji getTyp() {
        return typ;
    }

    /**
     * INFORMACJA_DODATKOWA_ROZSZERZENIE.TYP
     *
     * @param typ
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setTyp(TypRozszerzeniaInformacji typ) {
        this.typ = typ;
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        InformacjaDodatkowaRozszerzenie other = (InformacjaDodatkowaRozszerzenie) that;
        return (this.getId() == null ? other.getId() == null : this.getId().equals(other.getId()))
            && (this.getInformacjaDodatkowaId() == null ? other.getInformacjaDodatkowaId() == null : this.getInformacjaDodatkowaId().equals(other.getInformacjaDodatkowaId()))
            && (this.getWartoscTr() == null ? other.getWartoscTr() == null : this.getWartoscTr().equals(other.getWartoscTr()))
            && (this.getTyp() == null ? other.getTyp() == null : this.getTyp().equals(other.getTyp()));
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getId() == null) ? 0 : getId().hashCode());
        result = prime * result + ((getInformacjaDodatkowaId() == null) ? 0 : getInformacjaDodatkowaId().hashCode());
        result = prime * result + ((getWartoscTr() == null) ? 0 : getWartoscTr().hashCode());
        result = prime * result + ((getTyp() == null) ? 0 : getTyp().hashCode());
        return result;
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", id=").append(id);
        sb.append(", informacjaDodatkowaId=").append(informacjaDodatkowaId);
        sb.append(", wartoscTr=").append(wartoscTr);
        sb.append(", typ=").append(typ);
        sb.append("]");
        return sb.toString();
    }
}

==> dps-data-model-0.0.23-sources.jar: pl/topteam/dps/model/main_gen/InformacjaDodatkowaRozszerzenie.java <==
package pl.topteam.dps.model.main_gen;

import pl.topteam.dps.enums.TypRozszerzeniaInformacji;
import pl.topteam.dps.model.main_gen.GenericDPSObject;

public abstract class InformacjaDodatkowaRozszerzenie extends GenericDPSObject {
    /**
     * INFORMACJA_DODATKOWA_ROZSZERZENIE.ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long id;

    /**
     * INFORMACJA_DODATKOWA_ROZSZERZENIE.INFORMACJA_DODATKOWA_ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long informacjaDodatkowaId;

    /**
     * INFORMACJA_DODATKOWA_ROZSZERZENIE.WARTOSC_TR
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long wartoscTr;

    /**
     * INFORMACJA_DODATKOWA_ROZSZERZENIE.TYP
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private TypRozszerzeniaInformacji typ;

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    private static final long serialVersionUID = 1L;

    /**
     * @return INFORMACJA_DODATKOWA_ROZSZERZENIE.ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public Long getId() {
        return id;
    }

    /**
     * INFORMACJA_DODATKOWA_ROZSZERZENIE.ID
     *
     * @param id
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setId(Long id) {
        this.id = id;
    }

    /**
     * @return INFORMACJA_DODATKOWA_ROZSZERZENIE.INFORMACJA_DODATKOWA_ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Long getInformacjaDodatkowaId() {
        return informacjaDodatkowaId;
    }

    /**
     * INFORMACJA_DODATKOWA_ROZSZERZENIE.INFORMACJA_DODATKOWA_ID
     *
     * @param informacjaDodatkowaId
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setInformacjaDodatkowaId(Long informacjaDodatkowaId) {
        this.informacjaDodatkowaId = informacjaDodatkowaId;
    }

    /**
     * @return INFORMACJA_DODATKOWA_ROZSZERZENIE.WARTOSC_TR
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Long getWartoscTr() {
        return wartoscTr;
    }

    /**
     * INFORMACJA_DODATKOWA_ROZSZERZENIE.WARTOSC_TR
     *
     * @param wartoscTr
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setWartoscTr(Long wartoscTr) {
        this.wartoscTr = wartoscTr;
    }

    /**
     * @return INFORMACJA_DODATKOWA_ROZSZERZENIE.TYP
     * @mbggenerated 2014-03-13 16:02:38
     */
    public TypRozszerzeniaInformacji getTyp() {
        return typ;
    }

    /**
     * INFORMACJA_DODATKOWA_ROZSZERZENIE.TYP
     *
     * @param typ
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setTyp(TypRozszerzeniaInformacji typ) {
        this.typ = typ;
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        InformacjaDodatkowaRozszerzenie other = (InformacjaDodatkowaRozszerzenie) that;
        return (this.getId() == null ? other.getId() == null : this.getId().equals(other.getId()))
            && (this.getInformacjaDodatkowaId() == null ? other.getInformacjaDodatkowaId() == null : this.getInformacjaDodatkowaId().equals(other.getInformacjaDodatkowaId()))
            && (this.getWartoscTr() == null ? other.getWartoscTr() == null : this.getWartoscTr().equals(other.getWartoscTr()))
            && (this.getTyp() == null ? other.getTyp() == null : this.getTyp().equals(other.getTyp()));
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getId() == null) ? 0 : getId().hashCode());
        result = prime * result + ((getInformacjaDodatkowaId() == null) ? 0 : getInformacjaDodatkowaId().hashCode());
        result = prime * result + ((getWartoscTr() == null) ? 0 : getWartoscTr().hashCode());
        result = prime * result + ((getTyp() == null) ? 0 : getTyp().hashCode());
        return result;
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", id=").append(id);
        sb.append(", informacjaDodatkowaId=").append(informacjaDodatkowaId);
        sb.append(", wartoscTr=").append(wartoscTr);
        sb.append(", typ=").append(typ);
        sb.append("]");
        return sb.toString();
    }
}
